Records a latency metric on the currently active span.
Examples
# Record latency on the active span
with_trace("latency-demo", {
with_span("api-call", type = "custom", {
record_latency(0.45)
})
})
#> NULL
Records a latency metric on the currently active span.
# Record latency on the active span
with_trace("latency-demo", {
with_span("api-call", type = "custom", {
record_latency(0.45)
})
})
#> NULL